#!/bin/bash
. /etc/os-release
OS="$ID $VERSION_ID"

echo "Starting autoupdate"

#Check current calls
echo "Checking call count"
CNT=`asterisk -rx "core show calls" | grep "activ" | cut -d " " -f 1`
if [ "$CNT" != "0" ]
then
  echo "Can't update: there are $CNT calls currently"
	exit 1
fi 

#if we are on centos, we must check if xorcom-centos-release package is installed
if [ "$ID" = "centos" ]
then
  echo "Checking dependencies"
  CNT=`rpm -qa | grep xorcom-centos-release | wc -l`
	if [ "$CNT" == "0" ]
	then
		echo "Can't update: package xorcom-centos-release missing"
		exit 1
	fi
fi

#check Mysql running state
echo "Checking Mysql state"
mysql -u root -e "SHOW databases" > /dev/null
if [ "$?" != "0" ]
then 
  echo "Can't update: Mysql is not running, probably broken. please check and call support team"
	exit 1
fi

#check mysql data integrity
echo "Checking Mysql integrity"
mysqlcheck -u root --all-databases --check > /dev/null
if [ "$?" != "0" ]
then 
  echo "Can't update: Mysql data corrupted. Please check and call support team"
	exit 1
fi

#seems ok, update !
echo "Adding repositories"
if [ "$OS" = "centos 7" ]
then
  cat > /etc/yum.repos.d/ipconnect-direct.repo <<-EOF
	[ipconnect-direct]
	name=IPConnect software repository
	baseurl=http://repository.ipconnect.fr/Centos/7
	enabled=1
	gpgcheck=0

	[ipconnect-direct-beta]
	name=IPConnect software repository
	baseurl=http://repository.ipconnect.fr/Centos/7-beta
	enabled=0
	gpgcheck=0
EOF
elif [ "$OS" = "debian 8" ]
then
  echo "deb http://repository.ipconnect.fr/Debian/ jessie main" > /etc/apt/sources.list.d/ipconnect-direct.list
  apt-key adv --keyserver keyserver.ubuntu.com --recv-keys D072693A > /dev/null
else 
  echo "deb http://repository.ipconnect.fr/Debian/ bullseye main" > /etc/apt/sources.list.d/ipconnect-direct.list
  apt-key adv --keyserver keyserver.ubuntu.com --recv-keys D072693A > /dev/null
fi

echo "Updating..."
xlic auth
if [ "$OS" = "centos 7" ]
then
  yum clean expire-cache
	yes | yum update
else
  apt update;
	yes | apt full-upgrade
fi
exit $?